==> inv-api-1.4.8-20240816.013243-3-sources.jar: com/elitesland/inv/dto/invTro/InvTroRpcDTO.java <==
package com.elitesland.inv.dto.invTro;

import com.elitesland.inv.dto.invTrn.InvTrnDRpcDTO;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.List;

@Data
@ApiModel(description = "库存转移详情")
public class InvTroRpcDTO implements Serializable {

    private static final long serialVersionUID = -9067194839868175002L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty("转移单ID")
    private Long id;

    @ApiModelProperty("转移单号")
    private String docNo;

    @ApiModelProperty("创建日期")
    private LocalDateTime createTime;

    @ApiModelProperty("备注")
    private String remark;

    @ApiModelProperty("地址号")
    private Long addrNo;

    @ApiModelProperty("承运商")
    private String carrier;

    @ApiModelProperty("配送方式")
    private String deliverMethod;

    @ApiModelProperty("物流单号")
    private String logisDocNo;

    @ApiModelProperty("调拨原因")
    private String reasonCode;

    @ApiModelProperty("结算路径正逆向")
    private Boolean saleReturnFlag;

    @ApiModelProperty("收货仓库")
    private String toWhName;

    private Long fromWhId;

    @ApiModelProperty("发货仓库")
    private String fromWhName;

    @ApiModelProperty("发货公司")
    private Long fromOuId;

    @ApiModelProperty("收货公司")
    private Long toOuId;

    @ApiModelProperty("来源单据")
    private String relateDocCls;

    @ApiModelProperty("来源单据单号")
    private String relateDocNo;

    @ApiModelProperty("状态")
    private String docStatus;

    private List<InvTroDRpcDTO> invTrnDRpcDTOS;
}

==> inv-api-1.4.41-20241012.062851-1-sources.jar: com/elitesland/inv/dto/invTro/InvTroRpcDTO.java <==
package com.elitesland.inv.dto.invTro;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.List;

@Data
@ApiModel(description = "库存转移详情")
public class InvTroRpcDTO implements Serializable {

    private static final long serialVersionUID = -9067194839868175002L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty("转移单ID")
    private Long id;

    @ApiModelProperty("转移单号")
    private String docNo;

    @ApiModelProperty("创建日期")
    private LocalDateTime createTime;

    @ApiModelProperty("备注")
    private String remark;

    @ApiModelProperty("地址号")
    private Long addrNo;

    @ApiModelProperty("承运商")
    private String carrier;

    @ApiModelProperty("配送方式")
    private String deliverMethod;

    @ApiModelProperty("物流单号")
    private String logisDocNo;

    @ApiModelProperty("调拨原因")
    private String reasonCode;

    @ApiModelProperty("结算路径正逆向")
    private Boolean saleReturnFlag;

    @ApiModelProperty("收货仓库")
    private String toWhName;

    @ApiModelProperty("收货仓库编码")
    private String toWhCode;

    @ApiModelProperty("收货仓库id")
    private Long toWhId;

    private Long fromWhId;

    @ApiModelProperty("发货仓库编码")
    private String fromWhName;

    @ApiModelProperty("发货仓库")
    private String fromWhCode;

    @ApiModelProperty("发货公司")
    private Long fromOuId;

    @ApiModelProperty("收货公司")
    private Long toOuId;

    @ApiModelProperty("来源单据")
    private String relateDocCls;

    @ApiModelProperty("来源单据单号")
    private String relateDocNo;

    @ApiModelProperty("状态")
    private String docStatus;

    private List<InvTroDRpcDTO> invTrnDRpcDTOS;
}
